PrayerTimesHelper class

Constructors

PrayerTimesHelper()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getNextPrayer() PrayerTime?
Returns the next upcoming prayer
getTodaysPrayerTimes() List<PrayerTime>
Returns today's prayer times, using overrides if available
overrideTimes(Map<String, DateTime> customTimes) → void
Allow users or admins to override any default prayer time